# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: tensorflow_serving/config/logging_config.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from tensorboard_plugin_wit._vendor.tensorflow_serving.config import log_collector_config_pb2 as tensorflow__serving_dot_config_dot_log__collector__config__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='tensorflow_serving/config/logging_config.proto',
  package='tensorflow.serving',
  syntax='proto3',
  serialized_options=_b('\370\001\001'),
  serialized_pb=_b('\n.tensorflow_serving/config/logging_config.proto\x12\x12tensorflow.serving\x1a\x34tensorflow_serving/config/log_collector_config.proto\"\'\n\x0eSamplingConfig\x12\x15\n\rsampling_rate\x18\x01 \x01(\x01\"\x92\x01\n\rLoggingConfig\x12\x44\n\x14log_collector_config\x18\x01 \x01(\x0b\x32&.tensorflow.serving.LogCollectorConfig\x12;\n\x0fsampling_config\x18\x02 \x01(\x0b\x32\".tensorflow.serving.SamplingConfigB\x03\xf8\x01\x01\x62\x06proto3')
  ,
  dependencies=[tensorflow__serving_dot_config_dot_log__collector__config__pb2.DESCRIPTOR,])




_SAMPLINGCONFIG = _descriptor.Descriptor(
  name='SamplingConfig',
  full_name='tensorflow.serving.SamplingConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='sampling_rate', full_name='tensorflow.serving.SamplingConfig.sampling_rate', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=124,
  serialized_end=163,
)


_LOGGINGCONFIG = _descriptor.Descriptor(
  name='LoggingConfig',
  full_name='tensorflow.serving.LoggingConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='log_collector_config', full_name='tensorflow.serving.LoggingConfig.log_collector_config', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sampling_config', full_name='tensorflow.serving.LoggingConfig.sampling_config', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=166,
  serialized_end=312,
)

_LOGGINGCONFIG.fields_by_name['log_collector_config'].message_type = tensorflow__serving_dot_config_dot_log__collector__config__pb2._LOGCOLLECTORCONFIG
_LOGGINGCONFIG.fields_by_name['sampling_config'].message_type = _SAMPLINGCONFIG
DESCRIPTOR.message_types_by_name['SamplingConfig'] = _SAMPLINGCONFIG
DESCRIPTOR.message_types_by_name['LoggingConfig'] = _LOGGINGCONFIG
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

SamplingConfig = _reflection.GeneratedProtocolMessageType('SamplingConfig', (_message.Message,), dict(
  DESCRIPTOR = _SAMPLINGCONFIG,
  __module__ = 'tensorflow_serving.config.logging_config_pb2'
  # @@protoc_insertion_point(class_scope:tensorflow.serving.SamplingConfig)
  ))
_sym_db.RegisterMessage(SamplingConfig)

LoggingConfig = _reflection.GeneratedProtocolMessageType('LoggingConfig', (_message.Message,), dict(
  DESCRIPTOR = _LOGGINGCONFIG,
  __module__ = 'tensorflow_serving.config.logging_config_pb2'
  # @@protoc_insertion_point(class_scope:tensorflow.serving.LoggingConfig)
  ))
_sym_db.RegisterMessage(LoggingConfig)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# Copyright 2018 The TensorFlow Authors. All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
# ==============================================================================
"""The plugin serving the interactive inference tab."""

from __future__ import absolute_import
from __future__ import division
from __future__ import print_function

import copy
import io
import json
import logging
import math
import numpy as np
import os
import werkzeug
from werkzeug import wrappers
from six.moves import xrange  # pylint: disable=redefined-builtin

from google.protobuf import json_format
from grpc.framework.interfaces.face.face import AbortionError
from werkzeug import wrappers

import tensorflow as tf

from tensorboard.backend import http_util
from tensorboard.plugins import base_plugin
from tensorboard_plugin_wit._utils import common_utils
from tensorboard_plugin_wit._utils import inference_utils
from tensorboard_plugin_wit._utils import platform_utils

logger = logging.getLogger('tensorboard')


# Max number of examples to scan along the `examples_path` in order to return
# statistics and sampling for features.
NUM_EXAMPLES_TO_SCAN = 50

# Max number of mutants to show per feature (i.e. num of points along x-axis).
NUM_MUTANTS = 10

# Max number of examples to send in a single response.
# TODO(jameswex): Make dynamic based on example size.
MAX_EXAMPLES_TO_SEND = 10000

class WhatIfToolPlugin(base_plugin.TBPlugin):
  """Plugin for understanding/debugging model inference.
  """

  # This string field is used by TensorBoard to generate the paths for routes
  # provided by this plugin. It must thus be URL-friendly. This field is also
  # used to uniquely identify this plugin throughout TensorBoard. See BasePlugin
  # for details.
  plugin_name = 'whatif'
  examples = []
  updated_example_indices = set()
  sprite = None
  example_class = tf.train.Example

  # The standard name for encoded image features in TensorFlow.
  image_feature_name = 'image/encoded'

  # The width and height of the thumbnail for any images for Facets Dive.
  sprite_thumbnail_dim_px = 32

  # The vocab of inference class indices to label names for the model.
  label_vocab = []

  def __init__(self, context):
    """Constructs an interactive inference plugin for TensorBoard.

    Args:
      context: A base_plugin.TBContext instance.
    """
    self._logdir = context.logdir
    self._wit_data_dir = context.flags.wit_data_dir if context.flags else None

    self.custom_predict_fn = None
    if context.flags and context.flags.custom_predict_fn:
      try:
        import importlib.util as iu
        spec = iu.spec_from_file_location("custom_predict_fn", context.flags.custom_predict_fn)
        module = iu.module_from_spec(spec)
        spec.loader.exec_module(module)
        self.custom_predict_fn = module.custom_predict_fn
        logger.info("custom_predict_fn loaded.")

      except Exception as e:
        logger.error(str(e))
        logger.error("Failed to load the custom predict function.")
        logger.error("Have you defined a function named custom_predict_fn?")

  def get_plugin_apps(self):
    """Obtains a mapping between routes and handlers. Stores the logdir.

    Returns:
      A mapping between routes and handlers (functions that respond to
      requests).
    """
    return {
        '/index.js': self._serve_js,
        '/wit_tb_bin.html': self._serve_wit,
        '/wit_tb_bin.js': self._serve_wit_js,
        '/infer': self._infer,
        '/update_example': self._update_example,
        '/examples_from_path': self._examples_from_path_handler,
        '/sprite': self._serve_sprite,
        '/duplicate_example': self._duplicate_example,
        '/delete_example': self._delete_example,
        '/infer_mutants': self._infer_mutants_handler,
        '/eligible_features': self._eligible_features_from_example_handler,
        '/sort_eligible_features': self._sort_eligible_features_handler,
    }

  def is_active(self):
    """Determines whether this plugin is active.

    Returns:
      A boolean. Whether this plugin is active.
    """
    # TODO(jameswex): Maybe enable if config flags were specified?
    return False

  def frontend_metadata(self):
    return base_plugin.FrontendMetadata(
      es_module_path="/index.js",
      tab_name='What-If Tool')

  @wrappers.Request.application
  def _serve_js(self, request):
    del request  # unused
    filepath = os.path.join(os.path.dirname(__file__), "static", "index.js")
    with io.open(filepath, encoding='utf-8') as infile:
      contents = infile.read()
    return werkzeug.Response(contents, content_type="application/javascript")
  
  @wrappers.Request.application
  def _serve_wit(self, request):
    del request  # unused
    filepath = os.path.join(os.path.dirname(__file__), "static", "wit_tb_bin.html")
    with io.open(filepath, encoding='utf-8') as infile:
      contents = infile.read()
    return werkzeug.Response(contents, content_type="text/html")

  @wrappers.Request.application
  def _serve_wit_js(self, request):
    del request  # unused
    filepath = os.path.join(os.path.dirname(__file__), "static", "wit_tb_bin.js")
    with io.open(filepath, encoding='utf-8') as infile:
      contents = infile.read()
    return werkzeug.Response(contents, content_type="application/javascript")
  def generate_sprite(self, example_strings):
    # Generate a sprite image for the examples if the examples contain the
    # standard encoded image feature.
    feature_list = (self.examples[0].features.feature
        if self.example_class == tf.train.Example
        else self.examples[0].context.feature)
    self.sprite = (
        inference_utils.create_sprite_image(example_strings)
        if (len(self.examples) and self.image_feature_name in feature_list) else
        None)

  @wrappers.Request.application
  def _examples_from_path_handler(self, request):
    """Returns JSON of the specified examples.

    Args:
      request: A request that should contain 'examples_path' and 'max_examples'.

    Returns:
      JSON of up to max_examples of the examples in the path.
    """
    start_example = (int(request.args.get('start_example'))
        if request.args.get('start_example') else 0)
    if not start_example:
      examples_count = int(request.args.get('max_examples'))
      examples_path = request.args.get('examples_path')
      sampling_odds = float(request.args.get('sampling_odds'))
      self.example_class = (tf.train.SequenceExample
          if request.args.get('sequence_examples') == 'true'
          else tf.train.Example)
      try:
        platform_utils.throw_if_file_access_not_allowed(examples_path,
                                                        self._logdir,
                                                        self._wit_data_dir)
        example_strings = platform_utils.example_protos_from_path(
            examples_path, examples_count, parse_examples=False,
            sampling_odds=sampling_odds, example_class=self.example_class)
        self.examples = [
            self.example_class.FromString(ex) for ex in example_strings]
        self.generate_sprite(example_strings)
        self.updated_example_indices = set(range(len(self.examples)))
      except common_utils.InvalidUserInputError as e:
        logger.error('Data loading error: %s', e.message)
        return http_util.Respond(request, e.message,
                                'application/json', code=400)
      except Exception as e:
        return http_util.Respond(request, str(e),
                                'application/json', code=400)

    # Split examples from start_example to + max_examples
    # Send next start_example if necessary
    end_example = start_example + MAX_EXAMPLES_TO_SEND
    json_examples = [
        json_format.MessageToJson(example) for example in self.examples[
          start_example:end_example]
    ]
    if end_example >= len(self.examples):
      end_example = -1
    return http_util.Respond(
        request,
        {'examples': json_examples,
         'sprite': True if (self.sprite and not start_example) else False,
         'next': end_example},
        'application/json')

  @wrappers.Request.application
  def _serve_sprite(self, request):
    return http_util.Respond(request, self.sprite, 'image/png')

  @wrappers.Request.application
  def _update_example(self, request):
    """Updates the specified example.

    Args:
      request: A request that should contain 'index' and 'example'.

    Returns:
      An empty response.
    """
    if request.method != 'POST':
      return http_util.Respond(request, 'invalid non-POST request',
                               'application/json', code=405)
    example_json = request.form['example']
    index = int(request.form['index'])
    if index >= len(self.examples):
      return http_util.Respond(request, 'invalid index provided',
                               'application/json', code=400)
    new_example = self.example_class()
    json_format.Parse(example_json, new_example)
    self.examples[index] = new_example
    self.updated_example_indices.add(index)
    self.generate_sprite([ex.SerializeToString() for ex in self.examples])
    return http_util.Respond(request, {}, 'application/json')

  @wrappers.Request.application
  def _duplicate_example(self, request):
    """Duplicates the specified example.

    Args:
      request: A request that should contain 'index'.

    Returns:
      An empty response.
    """
    index = int(request.args.get('index'))
    if index >= len(self.examples):
      return http_util.Respond(request, 'invalid index provided',
                               'application/json', code=400)
    new_example = self.example_class()
    new_example.CopyFrom(self.examples[index])
    self.examples.append(new_example)
    self.updated_example_indices.add(len(self.examples) - 1)
    self.generate_sprite([ex.SerializeToString() for ex in self.examples])
    return http_util.Respond(request, {}, 'application/json')

  @wrappers.Request.application
  def _delete_example(self, request):
    """Deletes the specified example.

    Args:
      request: A request that should contain 'index'.

    Returns:
      An empty response.
    """
    index = int(request.args.get('index'))
    if index >= len(self.examples):
      return http_util.Respond(request, 'invalid index provided',
                               'application/json', code=400)
    del self.examples[index]
    self.updated_example_indices = set([
        i if i < index else i - 1 for i in self.updated_example_indices])
    self.generate_sprite([ex.SerializeToString() for ex in self.examples])
    return http_util.Respond(request, {}, 'application/json')

  def _parse_request_arguments(self, request):
    """Parses comma separated request arguments

    Args:
      request: A request that should contain 'inference_address', 'model_name',
        'model_version', 'model_signature'.

    Returns:
      A tuple of lists for model parameters
    """
    inference_addresses = request.args.get('inference_address').split(',')
    model_names = request.args.get('model_name').split(',')
    model_versions = request.args.get('model_version').split(',')
    model_signatures = request.args.get('model_signature').split(',')
    if len(model_names) != len(inference_addresses):
      raise common_utils.InvalidUserInputError('Every model should have a ' +
                                                'name and address.')
    return inference_addresses, model_names, model_versions, model_signatures

  @wrappers.Request.application
  def _infer(self, request):
    """Returns JSON for the `vz-line-chart`s for a feature.

    Args:
      request: A request that should contain 'inference_address', 'model_name',
        'model_type, 'model_version', 'model_signature' and 'label_vocab_path'.

    Returns:
      A list of JSON objects, one for each chart.
    """
    start_example = (int(request.args.get('start_example'))
        if request.args.get('start_example') else 0)
    if not start_example:
      label_vocab = inference_utils.get_label_vocab(
        request.args.get('label_vocab_path'))
      try:
        if request.method != 'GET':
          logger.error('%s requests are forbidden.', request.method)
          return http_util.Respond(request, 'invalid non-GET request',
                                      'application/json', code=405)

        (inference_addresses, model_names, model_versions,
            model_signatures) = self._parse_request_arguments(request)

        self.indices_to_infer = sorted(self.updated_example_indices)
        examples_to_infer = [self.examples[index] for index in self.indices_to_infer]
        self.infer_objs = []
        self.extra_outputs = []
        for model_num in xrange(len(inference_addresses)):
          serving_bundle = inference_utils.ServingBundle(
              inference_addresses[model_num],
              model_names[model_num],
              request.args.get('model_type'),
              model_versions[model_num],
              model_signatures[model_num],
              request.args.get('use_predict') == 'true',
              request.args.get('predict_input_tensor'),
              request.args.get('predict_output_tensor'),
              custom_predict_fn=self.custom_predict_fn)
          (predictions, extra_output) = inference_utils.run_inference_for_inference_results(
              examples_to_infer, serving_bundle)
          self.infer_objs.append(predictions)
          self.extra_outputs.append(extra_output)
        self.updated_example_indices = set()
      except AbortionError as e:
        logging.error(str(e))
        return http_util.Respond(request, e.details,
                                'application/json', code=400)
      except Exception as e:
        logging.error(str(e))
        return http_util.Respond(request, str(e),
                                'application/json', code=400)

    # Split results from start_example to + max_examples
    # Send next start_example if necessary
    end_example = start_example + MAX_EXAMPLES_TO_SEND

    def get_inferences_resp():
      sliced_infer_objs = [
        copy.deepcopy(infer_obj) for infer_obj in self.infer_objs]
      if request.args.get('model_type') == 'classification':
        for obj in sliced_infer_objs:
          obj['classificationResult']['classifications'][:] = obj[
            'classificationResult']['classifications'][
              start_example:end_example]
      else:
        for obj in sliced_infer_objs:
          obj['regressionResult']['regressions'][:] = obj['regressionResult'][
            'regressions'][start_example:end_example]
      return {'indices': self.indices_to_infer[start_example:end_example],
              'results': sliced_infer_objs}

    def get_extra_outputs_resp():
      sliced_extra_objs = [
        copy.deepcopy(infer_obj) for infer_obj in self.extra_outputs]
      for obj in sliced_extra_objs:
        if obj is not None:
          for key in obj:
            obj[key][:] = obj[key][start_example:end_example]
      return sliced_extra_objs

    try:
      inferences_resp = get_inferences_resp()
      extra_outputs_resp = get_extra_outputs_resp()
      resp = {'inferences': json.dumps(inferences_resp),
              'extraOutputs': json.dumps(extra_outputs_resp)}
      if end_example >= len(self.examples):
        end_example = -1
      if start_example == 0:
        resp['vocab'] = json.dumps(label_vocab)
      resp['next'] = end_example
      return http_util.Respond(request, resp, 'application/json')
    except Exception as e:
      logging.error(e)
      return http_util.Respond(request, str(e),
                               'application/json', code=400)

  @wrappers.Request.application
  def _eligible_features_from_example_handler(self, request):
    """Returns a list of JSON objects for each feature in the example.

    Args:
      request: A request for features.

    Returns:
      A list with a JSON object for each feature.
      Numeric features are represented as {name: observedMin: observedMax:}.
      Categorical features are represented as {name: samples:[]}.
    """
    features_list = inference_utils.get_eligible_features(
      self.examples[0: NUM_EXAMPLES_TO_SCAN], NUM_MUTANTS)
    return http_util.Respond(request, features_list, 'application/json')

  @wrappers.Request.application
  def _sort_eligible_features_handler(self, request):
    """Returns a sorted list of JSON objects for each feature in the example.

    The list is sorted by interestingness in terms of the resulting change in
    inference values across feature values, for partial dependence plots.

    Args:
      request: A request for sorted features.

    Returns:
      A sorted list with a JSON object for each feature.
      Numeric features are represented as
      {name: observedMin: observedMax: interestingness:}.
      Categorical features are represented as
      {name: samples:[] interestingness:}.
    """
    try:
      features_list = inference_utils.get_eligible_features(
          self.examples[0: NUM_EXAMPLES_TO_SCAN], NUM_MUTANTS)
      example_index = int(request.args.get('example_index', '0'))
      (inference_addresses, model_names, model_versions,
          model_signatures) = self._parse_request_arguments(request)
      chart_data = {}
      for feat in features_list:
        chart_data[feat['name']] = self._infer_mutants_impl(
          feat['name'], example_index,
          inference_addresses, model_names, request.args.get('model_type'),
          model_versions, model_signatures,
          request.args.get('use_predict') == 'true',
          request.args.get('predict_input_tensor'),
          request.args.get('predict_output_tensor'),
          feat['observedMin'] if 'observedMin' in feat else 0,
          feat['observedMax'] if 'observedMin' in feat else 0,
          None, custom_predict_fn=self.custom_predict_fn)
      features_list = inference_utils.sort_eligible_features(
        features_list, chart_data)
      return http_util.Respond(request, features_list, 'application/json')
    except common_utils.InvalidUserInputError as e:
      return http_util.Respond(request, e.message,
                               'application/json', code=400)
    except Exception as e:
      return http_util.Respond(request, str(e),
                               'application/json', code=400)

  @wrappers.Request.application
  def _infer_mutants_handler(self, request):
    """Returns JSON for the partial dependence plots for a feature.

    Args:
      request: A request that should contain 'feature_name', 'example_index',
         'inference_address', 'model_name', 'model_type', 'model_version', and
         'model_signature'.

    Returns:
      A list of JSON objects, one for each chart.
    """
    try:
      if request.method != 'GET':
        logger.error('%s requests are forbidden.', request.method)
        return http_util.Respond(request, 'invalid non-GET request',
                                 'application/json', code=405)

      example_index = int(request.args.get('example_index', '0'))
      feature_name = request.args.get('feature_name')
      (inference_addresses, model_names, model_versions,
          model_signatures) = self._parse_request_arguments(request)
      json_mapping = self._infer_mutants_impl(feature_name, example_index,
          inference_addresses, model_names, request.args.get('model_type'),
          model_versions, model_signatures,
          request.args.get('use_predict') == 'true',
          request.args.get('predict_input_tensor'),
          request.args.get('predict_output_tensor'),
          request.args.get('x_min'), request.args.get('x_max'),
          request.args.get('feature_index_pattern'),
          custom_predict_fn=self.custom_predict_fn)
      return http_util.Respond(request, json_mapping, 'application/json')
    except common_utils.InvalidUserInputError as e:
      return http_util.Respond(request, e.message,
                               'application/json', code=400)
    except Exception as e:
      return http_util.Respond(request, str(e),
                               'application/json', code=400)

  def _infer_mutants_impl(self, feature_name, example_index, inference_addresses,
      model_names, model_type, model_versions, model_signatures, use_predict,
      predict_input_tensor, predict_output_tensor, x_min, x_max,
      feature_index_pattern, custom_predict_fn):
    """Helper for generating PD plots for a feature."""
    examples = (self.examples if example_index == -1
                else [self.examples[example_index]])
    serving_bundles = []
    for model_num in xrange(len(inference_addresses)):
      serving_bundles.append(inference_utils.ServingBundle(
          inference_addresses[model_num],
          model_names[model_num],
          model_type,
          model_versions[model_num],
          model_signatures[model_num],
          use_predict,
          predict_input_tensor,
          predict_output_tensor,
          custom_predict_fn=custom_predict_fn))

    viz_params = inference_utils.VizParams(
        x_min, x_max,
        self.examples[0:NUM_EXAMPLES_TO_SCAN], NUM_MUTANTS,
        feature_index_pattern)
    return inference_utils.mutant_charts_for_feature(
        examples, feature_name, serving_bundles, viz_params)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: tensorflow_serving/apis/get_model_status.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from tensorboard_plugin_wit._vendor.tensorflow_serving.apis import model_pb2 as tensorflow__serving_dot_apis_dot_model__pb2
from tensorboard_plugin_wit._vendor.tensorflow_serving.util import status_pb2 as tensorflow__serving_dot_util_dot_status__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='tensorflow_serving/apis/get_model_status.proto',
  package='tensorflow.serving',
  syntax='proto3',
  serialized_options=_b('\370\001\001'),
  serialized_pb=_b('\n.tensorflow_serving/apis/get_model_status.proto\x12\x12tensorflow.serving\x1a#tensorflow_serving/apis/model.proto\x1a$tensorflow_serving/util/status.proto\"J\n\x15GetModelStatusRequest\x12\x31\n\nmodel_spec\x18\x01 \x01(\x0b\x32\x1d.tensorflow.serving.ModelSpec\"\xe8\x01\n\x12ModelVersionStatus\x12\x0f\n\x07version\x18\x01 \x01(\x03\x12;\n\x05state\x18\x02 \x01(\x0e\x32,.tensorflow.serving.ModelVersionStatus.State\x12/\n\x06status\x18\x03 \x01(\x0b\x32\x1f.tensorflow.serving.StatusProto\"S\n\x05State\x12\x0b\n\x07UNKNOWN\x10\x00\x12\t\n\x05START\x10\n\x12\x0b\n\x07LOADING\x10\x14\x12\r\n\tAVAILABLE\x10\x1e\x12\r\n\tUNLOADING\x10(\x12\x07\n\x03\x45ND\x10\x32\"^\n\x16GetModelStatusResponse\x12\x44\n\x14model_version_status\x18\x01 \x03(\x0b\x32&.tensorflow.serving.ModelVersionStatusB\x03\xf8\x01\x01\x62\x06proto3')
  ,
  dependencies=[tensorflow__serving_dot_apis_dot_model__pb2.DESCRIPTOR,tensorflow__serving_dot_util_dot_status__pb2.DESCRIPTOR,])



_MODELVERSIONSTATUS_STATE = _descriptor.EnumDescriptor(
  name='State',
  full_name='tensorflow.serving.ModelVersionStatus.State',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='START', index=1, number=10,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LOADING', index=2, number=20,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='AVAILABLE', index=3, number=30,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='UNLOADING', index=4, number=40,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='END', index=5, number=50,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=371,
  serialized_end=454,
)
_sym_db.RegisterEnumDescriptor(_MODELVERSIONSTATUS_STATE)


_GETMODELSTATUSREQUEST = _descriptor.Descriptor(
  name='GetModelStatusRequest',
  full_name='tensorflow.serving.GetModelStatusRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='model_spec', full_name='tensorflow.serving.GetModelStatusRequest.model_spec', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=145,
  serialized_end=219,
)


_MODELVERSIONSTATUS = _descriptor.Descriptor(
  name='ModelVersionStatus',
  full_name='tensorflow.serving.ModelVersionStatus',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='version', full_name='tensorflow.serving.ModelVersionStatus.version', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='state', full_name='tensorflow.serving.ModelVersionStatus.state', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='status', full_name='tensorflow.serving.ModelVersionStatus.status', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _MODELVERSIONSTATUS_STATE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=222,
  serialized_end=454,
)


_GETMODELSTATUSRESPONSE = _descriptor.Descriptor(
  name='GetModelStatusResponse',
  full_name='tensorflow.serving.GetModelStatusResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='model_version_status', full_name='tensorflow.serving.GetModelStatusResponse.model_version_status', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=456,
  serialized_end=550,
)

_GETMODELSTATUSREQUEST.fields_by_name['model_spec'].message_type = tensorflow__serving_dot_apis_dot_model__pb2._MODELSPEC
_MODELVERSIONSTATUS.fields_by_name['state'].enum_type = _MODELVERSIONSTATUS_STATE
_MODELVERSIONSTATUS.fields_by_name['status'].message_type = tensorflow__serving_dot_util_dot_status__pb2._STATUSPROTO
_MODELVERSIONSTATUS_STATE.containing_type = _MODELVERSIONSTATUS
_GETMODELSTATUSRESPONSE.fields_by_name['model_version_status'].message_type = _MODELVERSIONSTATUS
DESCRIPTOR.message_types_by_name['GetModelStatusRequest'] = _GETMODELSTATUSREQUEST
DESCRIPTOR.message_types_by_name['ModelVersionStatus'] = _MODELVERSIONSTATUS
DESCRIPTOR.message_types_by_name['GetModelStatusResponse'] = _GETMODELSTATUSRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

GetModelStatusRequest = _reflection.GeneratedProtocolMessageType('GetModelStatusRequest', (_message.Message,), dict(
  DESCRIPTOR = _GETMODELSTATUSREQUEST,
  __module__ = 'tensorflow_serving.apis.get_model_status_pb2'
  # @@protoc_insertion_point(class_scope:tensorflow.serving.GetModelStatusRequest)
  ))
_sym_db.RegisterMessage(GetModelStatusRequest)

ModelVersionStatus = _reflection.GeneratedProtocolMessageType('ModelVersionStatus', (_message.Message,), dict(
  DESCRIPTOR = _MODELVERSIONSTATUS,
  __module__ = 'tensorflow_serving.apis.get_model_status_pb2'
  # @@protoc_insertion_point(class_scope:tensorflow.serving.ModelVersionStatus)
  ))
_sym_db.RegisterMessage(ModelVersionStatus)

GetModelStatusResponse = _reflection.GeneratedProtocolMessageType('GetModelStatusResponse', (_message.Message,), dict(
  DESCRIPTOR = _GETMODELSTATUSRESPONSE,
  __module__ = 'tensorflow_serving.apis.get_model_status_pb2'
  # @@protoc_insertion_point(class_scope:tensorflow.serving.GetModelStatusResponse)
  ))
_sym_db.RegisterMessage(GetModelStatusResponse)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: tensorflow_serving/apis/prediction_log.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from tensorboard_plugin_wit._vendor.tensorflow_serving.apis import classification_pb2 as tensorflow__serving_dot_apis_dot_classification__pb2
from tensorboard_plugin_wit._vendor.tensorflow_serving.apis import inference_pb2 as tensorflow__serving_dot_apis_dot_inference__pb2
from tensorboard_plugin_wit._vendor.tensorflow_serving.apis import predict_pb2 as tensorflow__serving_dot_apis_dot_predict__pb2
from tensorboard_plugin_wit._vendor.tensorflow_serving.apis import regression_pb2 as tensorflow__serving_dot_apis_dot_regression__pb2
from tensorboard_plugin_wit._vendor.tensorflow_serving.apis import session_service_pb2 as tensorflow__serving_dot_apis_dot_session__service__pb2
from tensorboard_plugin_wit._vendor.tensorflow_serving.core import logging_pb2 as tensorflow__serving_dot_core_dot_logging__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='tensorflow_serving/apis/prediction_log.proto',
  package='tensorflow.serving',
  syntax='proto3',
  serialized_options=_b('\370\001\001'),
  serialized_pb=_b('\n,tensorflow_serving/apis/prediction_log.proto\x12\x12tensorflow.serving\x1a,tensorflow_serving/apis/classification.proto\x1a\'tensorflow_serving/apis/inference.proto\x1a%tensorflow_serving/apis/predict.proto\x1a(tensorflow_serving/apis/regression.proto\x1a-tensorflow_serving/apis/session_service.proto\x1a%tensorflow_serving/core/logging.proto\"\x87\x01\n\x0b\x43lassifyLog\x12:\n\x07request\x18\x01 \x01(\x0b\x32).tensorflow.serving.ClassificationRequest\x12<\n\x08response\x18\x02 \x01(\x0b\x32*.tensorflow.serving.ClassificationResponse\"~\n\nRegressLog\x12\x36\n\x07request\x18\x01 \x01(\x0b\x32%.tensorflow.serving.RegressionRequest\x12\x38\n\x08response\x18\x02 \x01(\x0b\x32&.tensorflow.serving.RegressionResponse\"x\n\nPredictLog\x12\x33\n\x07request\x18\x01 \x01(\x0b\x32\".tensorflow.serving.PredictRequest\x12\x35\n\x08response\x18\x02 \x01(\x0b\x32#.tensorflow.serving.PredictResponse\"\x8d\x01\n\x11MultiInferenceLog\x12:\n\x07request\x18\x01 \x01(\x0b\x32).tensorflow.serving.MultiInferenceRequest\x12<\n\x08response\x18\x02 \x01(\x0b\x32*.tensorflow.serving.MultiInferenceResponse\"\x81\x01\n\rSessionRunLog\x12\x36\n\x07request\x18\x01 \x01(\x0b\x32%.tensorflow.serving.SessionRunRequest\x12\x38\n\x08response\x18\x02 \x01(\x0b\x32&.tensorflow.serving.SessionRunResponse\"\xfd\x02\n\rPredictionLog\x12\x35\n\x0clog_metadata\x18\x01 \x01(\x0b\x32\x1f.tensorflow.serving.LogMetadata\x12\x37\n\x0c\x63lassify_log\x18\x02 \x01(\x0b\x32\x1f.tensorflow.serving.ClassifyLogH\x00\x12\x35\n\x0bregress_log\x18\x03 \x01(\x0b\x32\x1e.tensorflow.serving.RegressLogH\x00\x12\x35\n\x0bpredict_log\x18\x06 \x01(\x0b\x32\x1e.tensorflow.serving.PredictLogH\x00\x12\x44\n\x13multi_inference_log\x18\x04 \x01(\x0b\x32%.tensorflow.serving.MultiInferenceLogH\x00\x12<\n\x0fsession_run_log\x18\x05 \x01(\x0b\x32!.tensorflow.serving.SessionRunLogH\x00\x42\n\n\x08log_typeB\x03\xf8\x01\x01\x62\x06proto3')
  ,
  dependencies=[tensorflow__serving_dot_apis_dot_classification__pb2.DESCRIPTOR,tensorflow__serving_dot_apis_dot_inference__pb2.DESCRIPTOR,tensorflow__serving_dot_apis_dot_predict__pb2.DESCRIPTOR,tensorflow__serving_dot_apis_dot_regression__pb2.DESCRIPTOR,tensorflow__serving_dot_apis_dot_session__service__pb2.DESCRIPTOR,tensorflow__serving_dot_core_dot_logging__pb2.DESCRIPTOR,])




_CLASSIFYLOG = _descriptor.Descriptor(
  name='ClassifyLog',
  full_name='tensorflow.serving.ClassifyLog',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='request', full_name='tensorflow.serving.ClassifyLog.request', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='response', full_name='tensorflow.serving.ClassifyLog.response', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=323,
  serialized_end=458,
)


_REGRESSLOG = _descriptor.Descriptor(
  name='RegressLog',
  full_name='tensorflow.serving.RegressLog',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='request', full_name='tensorflow.serving.RegressLog.request', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='response', full_name='tensorflow.serving.RegressLog.response', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=460,
  serialized_end=586,
)


_PREDICTLOG = _descriptor.Descriptor(
  name='PredictLog',
  full_name='tensorflow.serving.PredictLog',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='request', full_name='tensorflow.serving.PredictLog.request', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='response', full_name='tensorflow.serving.PredictLog.response', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=588,
  serialized_end=708,
)


_MULTIINFERENCELOG = _descriptor.Descriptor(
  name='MultiInferenceLog',
  full_name='tensorflow.serving.MultiInferenceLog',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='request', full_name='tensorflow.serving.MultiInferenceLog.request', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='response', full_name='tensorflow.serving.MultiInferenceLog.response', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=711,
  serialized_end=852,
)


_SESSIONRUNLOG = _descriptor.Descriptor(
  name='SessionRunLog',
  full_name='tensorflow.serving.SessionRunLog',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='request', full_name='tensorflow.serving.SessionRunLog.request', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='response', full_name='tensorflow.serving.SessionRunLog.response', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=855,
  serialized_end=984,
)


_PREDICTIONLOG = _descriptor.Descriptor(
  name='PredictionLog',
  full_name='tensorflow.serving.PredictionLog',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='log_metadata', full_name='tensorflow.serving.PredictionLog.log_metadata', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='classify_log', full_name='tensorflow.serving.PredictionLog.classify_log', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='regress_log', full_name='tensorflow.serving.PredictionLog.regress_log', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='predict_log', full_name='tensorflow.serving.PredictionLog.predict_log', index=3,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='multi_inference_log', full_name='tensorflow.serving.PredictionLog.multi_inference_log', index=4,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='session_run_log', full_name='tensorflow.serving.PredictionLog.session_run_log', index=5,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='log_type', full_name='tensorflow.serving.PredictionLog.log_type',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=987,
  serialized_end=1368,
)

_CLASSIFYLOG.fields_by_name['request'].message_type = tensorflow__serving_dot_apis_dot_classification__pb2._CLASSIFICATIONREQUEST
_CLASSIFYLOG.fields_by_name['response'].message_type = tensorflow__serving_dot_apis_dot_classification__pb2._CLASSIFICATIONRESPONSE
_REGRESSLOG.fields_by_name['request'].message_type = tensorflow__serving_dot_apis_dot_regression__pb2._REGRESSIONREQUEST
_REGRESSLOG.fields_by_name['response'].message_type = tensorflow__serving_dot_apis_dot_regression__pb2._REGRESSIONRESPONSE
_PREDICTLOG.fields_by_name['request'].message_type = tensorflow__serving_dot_apis_dot_predict__pb2._PREDICTREQUEST
_PREDICTLOG.fields_by_name['response'].message_type = tensorflow__serving_dot_apis_dot_predict__pb2._PREDICTRESPONSE
_MULTIINFERENCELOG.fields_by_name['request'].message_type = tensorflow__serving_dot_apis_dot_inference__pb2._MULTIINFERENCEREQUEST
_MULTIINFERENCELOG.fields_by_name['response'].message_type = tensorflow__serving_dot_apis_dot_inference__pb2._MULTIINFERENCERESPONSE
_SESSIONRUNLOG.fields_by_name['request'].message_type = tensorflow__serving_dot_apis_dot_session__service__pb2._SESSIONRUNREQUEST
_SESSIONRUNLOG.fields_by_name['response'].message_type = tensorflow__serving_dot_apis_dot_session__service__pb2._SESSIONRUNRESPONSE
_PREDICTIONLOG.fields_by_name['log_metadata'].message_type = tensorflow__serving_dot_core_dot_logging__pb2._LOGMETADATA
_PREDICTIONLOG.fields_by_name['classify_log'].message_type = _CLASSIFYLOG
_PREDICTIONLOG.fields_by_name['regress_log'].message_type = _REGRESSLOG
_PREDICTIONLOG.fields_by_name['predict_log'].message_type = _PREDICTLOG
_PREDICTIONLOG.fields_by_name['multi_inference_log'].message_type = _MULTIINFERENCELOG
_PREDICTIONLOG.fields_by_name['session_run_log'].message_type = _SESSIONRUNLOG
_PREDICTIONLOG.oneofs_by_name['log_type'].fields.append(
  _PREDICTIONLOG.fields_by_name['classify_log'])
_PREDICTIONLOG.fields_by_name['classify_log'].containing_oneof = _PREDICTIONLOG.oneofs_by_name['log_type']
_PREDICTIONLOG.oneofs_by_name['log_type'].fields.append(
  _PREDICTIONLOG.fields_by_name['regress_log'])
_PREDICTIONLOG.fields_by_name['regress_log'].containing_oneof = _PREDICTIONLOG.oneofs_by_name['log_type']
_PREDICTIONLOG.oneofs_by_name['log_type'].fields.append(
  _PREDICTIONLOG.fields_by_name['predict_log'])
_PREDICTIONLOG.fields_by_name['predict_log'].containing_oneof = _PREDICTIONLOG.oneofs_by_name['log_type']
_PREDICTIONLOG.oneofs_by_name['log_type'].fields.append(
  _PREDICTIONLOG.fields_by_name['multi_inference_log'])
_PREDICTIONLOG.fields_by_name['multi_inference_log'].containing_oneof = _PREDICTIONLOG.oneofs_by_name['log_type']
_PREDICTIONLOG.oneofs_by_name['log_type'].fields.append(
  _PREDICTIONLOG.fields_by_name['session_run_log'])
_PREDICTIONLOG.fields_by_name['session_run_log'].containing_oneof = _PREDICTIONLOG.oneofs_by_name['log_type']
DESCRIPTOR.message_types_by_name['ClassifyLog'] = _CLASSIFYLOG
DESCRIPTOR.message_types_by_name['RegressLog'] = _REGRESSLOG
DESCRIPTOR.message_types_by_name['PredictLog'] = _PREDICTLOG
DESCRIPTOR.message_types_by_name['MultiInferenceLog'] = _MULTIINFERENCELOG
DESCRIPTOR.message_types_by_name['SessionRunLog'] = _SESSIONRUNLOG
DESCRIPTOR.message_types_by_name['PredictionLog'] = _PREDICTIONLOG
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ClassifyLog = _reflection.GeneratedProtocolMessageType('ClassifyLog', (_message.Message,), dict(
  DESCRIPTOR = _CLASSIFYLOG,
  __module__ = 'tensorflow_serving.apis.prediction_log_pb2'
  # @@protoc_insertion_point(class_scope:tensorflow.serving.ClassifyLog)
  ))
_sym_db.RegisterMessage(ClassifyLog)

RegressLog = _reflection.GeneratedProtocolMessageType('RegressLog', (_message.Message,), dict(
  DESCRIPTOR = _REGRESSLOG,
  __module__ = 'tensorflow_serving.apis.prediction_log_pb2'
  # @@protoc_insertion_point(class_scope:tensorflow.serving.RegressLog)
  ))
_sym_db.RegisterMessage(RegressLog)

PredictLog = _reflection.GeneratedProtocolMessageType('PredictLog', (_message.Message,), dict(
  DESCRIPTOR = _PREDICTLOG,
  __module__ = 'tensorflow_serving.apis.prediction_log_pb2'
  # @@protoc_insertion_point(class_scope:tensorflow.serving.PredictLog)
  ))
_sym_db.RegisterMessage(PredictLog)

MultiInferenceLog = _reflection.GeneratedProtocolMessageType('MultiInferenceLog', (_message.Message,), dict(
  DESCRIPTOR = _MULTIINFERENCELOG,
  __module__ = 'tensorflow_serving.apis.prediction_log_pb2'
  # @@protoc_insertion_point(class_scope:tensorflow.serving.MultiInferenceLog)
  ))
_sym_db.RegisterMessage(MultiInferenceLog)

SessionRunLog = _reflection.GeneratedProtocolMessageType('SessionRunLog', (_message.Message,), dict(
  DESCRIPTOR = _SESSIONRUNLOG,
  __module__ = 'tensorflow_serving.apis.prediction_log_pb2'
  # @@protoc_insertion_point(class_scope:tensorflow.serving.SessionRunLog)
  ))
_sym_db.RegisterMessage(SessionRunLog)

PredictionLog = _reflection.GeneratedProtocolMessageType('PredictionLog', (_message.Message,), dict(
  DESCRIPTOR = _PREDICTIONLOG,
  __module__ = 'tensorflow_serving.apis.prediction_log_pb2'
  # @@protoc_insertion_point(class_scope:tensorflow.serving.PredictionLog)
  ))
_sym_db.RegisterMessage(PredictionLog)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
